Struct Wpcr0
#[repr(transparent)]pub struct Wpcr0(pub u32);Expand description
DSI Wrapper PHY configuration register 0.
Tuple Fields
0: u32Implementations
impl Wpcr0
impl Wpcr0
pub const fn set_swcl(&mut self, val: bool)
pub const fn set_swcl(&mut self, val: bool)
Swap clock lane pins This bit swaps the pins on clock lane.
pub const fn set_swdl0(&mut self, val: bool)
pub const fn set_swdl0(&mut self, val: bool)
Swap data lane 0 pins This bit swaps the pins on data lane 0.
pub const fn set_swdl1(&mut self, val: bool)
pub const fn set_swdl1(&mut self, val: bool)
Swap data lane 1 pins This bit swaps the pins on clock lane.
pub const fn ftxsmcl(&self) -> bool
pub const fn ftxsmcl(&self) -> bool
Force in TX Stop mode the clock lane This bit forces the clock lane in TX stop mode. It is used to initialize a lane module in transmit mode. It causes the lane module to immediately jump to transmit control mode and to begin transmitting a stop state (LP-11). It can be used to go back in TX mode after a wrong BTA sequence.
pub const fn set_ftxsmcl(&mut self, val: bool)
pub const fn set_ftxsmcl(&mut self, val: bool)
Force in TX Stop mode the clock lane This bit forces the clock lane in TX stop mode. It is used to initialize a lane module in transmit mode. It causes the lane module to immediately jump to transmit control mode and to begin transmitting a stop state (LP-11). It can be used to go back in TX mode after a wrong BTA sequence.
pub const fn ftxsmdl(&self) -> bool
pub const fn ftxsmdl(&self) -> bool
Force in TX Stop mode the data lanes This bit forces the data lanes in TX stop mode. It is used to initialize a lane module in transmit mode. It causes the lane module to immediately jump to transmit control mode and to begin transmitting a stop state (LP-11). It can be used to go back in TX mode after a wrong BTA sequence.
pub const fn set_ftxsmdl(&mut self, val: bool)
pub const fn set_ftxsmdl(&mut self, val: bool)
Force in TX Stop mode the data lanes This bit forces the data lanes in TX stop mode. It is used to initialize a lane module in transmit mode. It causes the lane module to immediately jump to transmit control mode and to begin transmitting a stop state (LP-11). It can be used to go back in TX mode after a wrong BTA sequence.